@@ -1,5 +1,4 @@
 from .version import __version__ as __version__
-from .project import project as project
 
 from .base_state import (
     KeyAgreementException as KeyAgreementException,
@@ -16,5 +15,6 @@ from .types import (
     Bundle as Bundle,
     Header as Header,
     IdentityKeyFormat as IdentityKeyFormat,
+    JSONType as JSONType,
     JSONObject as JSONObject
 )
